@@ -13,7 +13,7 @@ use URI;
 use URI::QueryParam;
 use URI::file;
 
-our $VERSION = '0.014';
+our $VERSION = '0.015';
 
 has dsn => sub { _dsn_from_path(shift->_tempfile_path) };
 has max_connections => 5;
@@ -205,7 +205,17 @@ C<mode=memory>) will create a temporary database, in-memory databases cannot be
 shared between connections, so subsequent calls to L</"db"> may return
 connections to completely different databases. For a temporary database that
 can be shared between connections and processes, pass a file path of C<:temp:>
-to store the database in a temporary file (this is the default).
+to store the database in a temporary directory (this is the default), or
+consider constructing a temporary directory yourself with L<File::Temp> if you
+need to reuse the filename. A temporary directory allows SQLite to create
+L<additional temporary files|https://www.sqlite.org/tempfiles.html> safely.
+
+  use File::Spec::Functions 'catfile';
+  use File::Temp;
+  use Mojo::SQLite;
+  my $tempdir = File::Temp->newdir; # Deleted when object goes out of scope
+  my $tempfile = catfile $tempdir, 'sqlite.db';
+  my $sql = Mojo::SQLite->new->from_filename($tempfile);
 
 =head1 EVENTS
 
